simplify.FraudCheck

Package simplify :: Class FraudCheck |
[hide private]
[frames] | no frames]

# Class FraudCheck

source code

    domain.Domain --+
                    |
                   FraudCheck

A FraudCheck object.

Instance Methods | [hide private]
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an FraudCheck object | source code
list(criteria=None, *auth_args) Retrieve FraudCheck objects. | source code
find(object_id, *auth_args) Retrieve a FraudCheck object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an FraudCheck object Parameters: `params` - a dict of parameters; valid keys are: `amount`: Amount of the transaction to be checked for fraud (in the smallest unit of your currency). Example: 100 = $1.00. This field is required if using â€œfullâ€ or â€œadvancedâ€ mode. `card => addressCity`: City of the cardholder. [max length: 50, min length: 2] `card => addressCountry`: Country code (ISO-3166-1-alpha-2 code) of residence of the cardholder. [max length: 2, min length: 2] `card => addressLine1`: Address of the cardholder. [max length: 255] `card => addressLine2`: Address of the cardholder if needed. [max length: 255] `card => addressState`: State of residence of the cardholder. State abbreviations should be used. [max length: 255] `card => addressZip`: Postal code of the cardholder. The postal code size is between 5 and 9 characters in length and only contains numbers or letters. [max length: 32] `card => cvc`: CVC security code of the card. This is the code on the back of the card. Example: 123 `card => expMonth`: Expiration month of the card. Format is MM. Example: January = 01 [min value: 1, max value: 12] `card => expYear`: Expiration year of the card. Format is YY. Example: 2013 = 13 [min value: 0, max value: 99] `card => name`: Name as it appears on the card. [max length: 50, min length: 2] `card => number`: Card number as it appears on the card. [max length: 19, min length: 13] `currency`: Currency code (ISO-4217) for the transaction to be checked for fraud. This field is required if using â€œfullâ€ or â€œadvancedâ€ mode. `description`: - Description of the fraud check. [max length: 255] `ipAddress`: IP Address of the customer for which the fraud check is to be done. [max length: 45] `mode`: Fraud check mode. â€œsimpleâ€ only does an AVS and CVC check; â€œadvancedâ€ does a complete fraud check, running the input against the set up rules. [valid values: simple, advanced, full, SIMPLE, ADVANCED, FULL] required `sessionId`: Session ID used during data collection. [max length: 255] `token`: Card token representing card details for the card to be checked. [max length: 255] `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a FraudCheck object

### list(criteria=None, *auth_args) Static Method | source code
Retrieve FraudCheck objects. Parameters: `criteria` - a dict of parameters; valid keys are: `filter` Filters to apply to the list. `max` Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20] `offset` Used in paging of the list. This is the start offset of the page. [min value: 0, default: 0] `sorting` Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either `asc` for ascending or `desc` for descending). Sortable properties are: `amount` `dateCreated` `fraudResult`. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an object which contains the list of FraudCheck objects in the <code>list</code> property and the total number of objects available for the given criteria in the <code>total</code> property.

### find(object_id, *auth_args) Static Method | source code
Retrieve a FraudCheck object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a FraudCheck object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `integratorAuthCode` Authorization code for the transaction. [max length: 255] `integratorAvsAddressResponse` AVS address response. [max length: 255] `integratorAvsZipResponse` AVS zip response. [max length: 255] `integratorCvcResponse` CVC response. [max length: 255] `integratorDeclineReason` Reason for the decline if applicable. [max length: 255] `integratorTransactionRef` Reference id for the transaction. [max length: 255] (required) `integratorTransactionStatus` Status of the transaction, valid values are "APPROVED", "DECLINED", "SETTLED", "REFUNDED" or "VOIDED". Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a FraudCheck object.